@@ -16,9 +16,12 @@
 */
 
 #include "ball.h"
+#include "settings.h"
+
+#include "core/display.h"
 
 //Line
-Line::Line(vec2f start, vec2f end) {
+Line::Line(vec2 start, vec2 end) {
 	this->start = start;
 	this->end   = end;
 }
@@ -28,16 +31,16 @@ Line::~Line() {
 
 // check if line intersects the plane of another line
 
-bool Line::intersects(Line& l, vec2f *p) {
-    vec2f a = end   - start;
-    vec2f b = l.end - l.start;
+bool Line::intersects(Line& l, vec2 *p) {
+    vec2 a = end   - start;
+    vec2 b = l.end - l.start;
 
     float d = a.x*b.y - a.y * b.x;
 
     //parallel test
     if (!d) return false;
 
-    vec2f w = start - l.start;
+    vec2 w = start - l.start;
 
     //check if outside either line segment
     float s = b.x * w.y - b.y * w.x;
@@ -60,21 +63,21 @@ bool Line::intersects(Line& l, vec2f *p) {
 ProjectedBall::ProjectedBall() {
 }
 
-ProjectedBall::ProjectedBall(const vec2f& pos, const vec2f& vel, const vec3f& colour, int dest_x, float eta, float size, float speed) {
-    init(pos, vel, colour, dest_x, eta, size, speed);
+ProjectedBall::ProjectedBall(const vec2& pos, const vec2& vel, const vec3& colour, int dest_x, float size) {
+    init(pos, vel, colour, dest_x, size);
 }
 
-void ProjectedBall::init(const vec2f& pos, const vec2f& vel, const vec3f& colour, int dest_x, float eta, float size, float speed) {
+void ProjectedBall::init(const vec2& pos, const vec2& vel, const vec3& colour, int dest_x, float size) {
+
     this->pos = pos;
     this->vel = vel;
     this->colour = colour;
-    this->speed = speed;
     this->size  = size;
-
     this->dest_x = dest_x;
-    this->start_x = (int) pos.x;
-    this->eta    = eta;
-    this->has_bounced=0;
+    
+    start_x = (int) pos.x;
+    
+    has_bounced=0;
     no_bounce = 0;
 
     project();
@@ -89,23 +92,24 @@ ProjectedBall::~ProjectedBall() {
 */
 
 void ProjectedBall::project() {
-    elapsed = 0.0f;
-    progress = 0.0f;
+    distance_travelled = 0.0f;
+    total_distance     = 0.0f;
+
     points.clear();
-    vec2f p = pos;
+    vec2 p = pos;
     points.push_back(p);
 
     //project current position and direction until it hits a wall or crosses dest_x
-    Line finish(vec2f(dest_x, 0), vec2f(dest_x, display.height));
-    Line top(vec2f(0,0), vec2f(display.width, 0));
-    Line bottom(vec2f(0,display.height), vec2f(display.width, display.height));
+    Line finish(vec2(dest_x, 0), vec2(dest_x, display.height));
+    Line top(vec2(0,0), vec2(display.width, 0));
+    Line bottom(vec2(0,display.height), vec2(display.width, display.height));
 
     //project far enough to cross a side of the screen
     float inc = display.width*2.0f;
 
     bool finished=false;
-    vec2f currvel = vel;
-    total_length=0;
+    vec2 currvel = vel;
+
     line_lengths.clear();
 
     while(!finished) {
@@ -118,7 +122,7 @@ void ProjectedBall::project() {
         debugLog("bottom = (%.2f, %.2f), (%.2f, %.2f)\n", bottom.start.x, bottom.start.y, bottom.end.x, bottom.end.y);
         */
 
-        vec2f intersect;
+        vec2 intersect;
 
         //find nearest intersected plane
 
@@ -135,17 +139,17 @@ void ProjectedBall::project() {
             break;
         }
 
-        float length = (intersect-p).length();
+        float line_length = glm::length(intersect-p);
 
         p = intersect;
         points.push_back(intersect);
-        line_lengths.push_back(length);
-        total_length +=length;
+        line_lengths.push_back(line_length);
+        total_distance += line_length;
     }
 }
 
 bool ProjectedBall::isFinished() const {
-    return has_bounced && elapsed>=eta;
+    return has_bounced && distance_travelled >= total_distance;
 }
 
 void ProjectedBall::bounce() {
@@ -164,20 +168,12 @@ void ProjectedBall::bounce() {
     has_bounced=true;
 }
 
-bool ProjectedBall::arrived() const {
-    return elapsed>=eta;
-}
-
-void ProjectedBall::setElapsed(float e) {
-    elapsed =e;
-}
-
 float ProjectedBall::arrivalTime() {
-    return (eta-elapsed)/speed;
+    return (total_distance-distance_travelled) / (settings.pitch_speed * (float) display.width);
 }
 
 float ProjectedBall::getProgress() const {
-    return progress;
+    return (distance_travelled/total_distance);
 }
 
 void ProjectedBall::dontBounce() {
@@ -185,28 +181,23 @@ void ProjectedBall::dontBounce() {
 }
 
 void ProjectedBall::logic(float dt) {
-    elapsed += (dt * speed);
-    progress = elapsed / eta;
+    distance_travelled += dt * settings.pitch_speed * (float) display.width;
+
+    if(distance_travelled >= total_distance) {
 
-    if(progress>1.0f) {
         if(!has_bounced) {
             bounce();
-            return;
         }
-
         return;
     }
 
     //number of lines
     int nolines = points.size()-1;
 
-    //progress
-    float currposf = progress * total_length;
-
     int pointno = 0;
     float len=0;
 
-    while(pointno<nolines && len+line_lengths[pointno]<currposf) {
+    while(pointno<nolines && len+line_lengths[pointno] < distance_travelled) {
         len+=line_lengths[pointno];
         pointno++;
     }
@@ -221,15 +212,15 @@ void ProjectedBall::logic(float dt) {
         return;
     }
 
-    vec2f from = points[pointno];
-    vec2f to   = points[pointno+1];
+    vec2 from = points[pointno];
+    vec2 to   = points[pointno+1];
 
-    float linepos = (currposf - len)/line_lengths[pointno];
+    float linepos = (distance_travelled - len)/line_lengths[pointno];
 
     this->pos = from + ((to-from)*linepos);
 }
 
-vec2f ProjectedBall::finish() {
+vec2 ProjectedBall::finish() {
     return points[points.size()-1];
 }
 
